@@ -1,5 +1,5 @@
 package Test::Mock::Wrapper;
-$Test::Mock::Wrapper::VERSION = '0.05';
+$Test::Mock::Wrapper::VERSION = '0.06';
 use strict;
 use warnings;
 use base qw(Exporter);
@@ -17,7 +17,7 @@ Test::Mock::Wrapper
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -124,6 +124,9 @@ sub new {
     if (! ref($object)) {
 	eval "package $object; use metaclass;";  
 	my $metaclass = $object->meta;
+
+	$metaclass->make_mutable if($metaclass->is_immutable);
+
 	$controll->{__metaclass} = $metaclass;
 	foreach my $method_name ($metaclass->get_method_list){
 	    push @{ $controll->{__wrapped_symbols} }, {name => $method_name, symbol => $metaclass->find_method_by_name($method_name)};
@@ -144,9 +147,11 @@ sub DESTROY {
     my $controll = shift;
     no strict qw(refs);
     no warnings 'redefine', 'prototype';
-    foreach my $sym (@{ $controll->{__wrapped_symbols} }){
-	if ($sym->{symbol}) {
-	    $controll->{__metaclass}->add_method($sym->{name}, $sym->{symbol}->body);
+    if ($controll->{__metaclass}) {
+	foreach my $sym (@{ $controll->{__wrapped_symbols} }){
+	    if ($sym->{symbol}) {
+		$controll->{__metaclass}->add_method($sym->{name}, $sym->{symbol}->body);
+	    }
 	}
     }
 }
@@ -382,7 +387,7 @@ sub verify {
 
 
 package Test::Mock::Wrapped;
-$Test::Mock::Wrapped::VERSION = '0.05';
+$Test::Mock::Wrapped::VERSION = '0.06';
 use Carp;
 use Scalar::Util qw(weaken isweak);
 use vars qw(@ISA);
@@ -411,7 +416,6 @@ sub AUTOLOAD {
 	}
 	else {
 	    my $pack = ref($self->{__object});
-	    print STDERR "Failing from wrapper autoload\n";
 	    croak qq{Can't locate object method "$method" via package "$pack"};
 	}
     }
